@@ -1,4 +1,4 @@
-use nxui::window::demowindow::DemoWindow;
+use nxui::demo::demowindow::DemoWindow;
 
 fn main() {
     let win = DemoWindow::new();
