@@ -61,6 +61,7 @@ impl MessageBox {
                 Win32::Foundation::*, Win32::System::Threading::*,
                 Win32::UI::WindowsAndMessaging::*,
             };
+            enable_visual_style();
             let event = CreateEventW(std::ptr::null(), 1, 0, std::ptr::null());
             SetEvent(event);
             WaitForSingleObject(event, 0);
@@ -126,3 +127,44 @@ impl MessageBox {
         result
     }
 }
+
+/// Enabling Visual Style
+#[cfg(windows)]
+fn enable_visual_style() {
+    use winapi::shared::minwindef::{ULONG, DWORD};
+    use winapi::shared::basetsd::ULONG_PTR;
+    use winapi::um::winbase::{ACTCTXW, CreateActCtxW, ActivateActCtx};
+    use winapi::um::sysinfoapi::GetSystemDirectoryW;
+    use std::{mem, ptr};
+    use windows_sys::Win32::Foundation::MAX_PATH;
+
+    const ACTCTX_FLAG_RESOURCE_NAME_VALID: DWORD = 0x008;
+    const ACTCTX_FLAG_SET_PROCESS_DEFAULT: DWORD = 0x010;
+    const ACTCTX_FLAG_ASSEMBLY_DIRECTORY_VALID: DWORD = 0x004;
+
+    let mut sys_dir: Vec<u16> = Vec::with_capacity(MAX_PATH as usize);
+    unsafe {
+        sys_dir.set_len(MAX_PATH as usize);
+        GetSystemDirectoryW(sys_dir.as_mut_ptr(), MAX_PATH as u32);
+    }
+
+    let mut source = "shell32.dll".encode_utf16().collect::<Vec<u16>>();
+
+    let mut activation_cookie: ULONG_PTR = 0;
+    let mut act_ctx = ACTCTXW {
+        cbSize: mem::size_of::<ACTCTXW> as ULONG,
+        dwFlags: ACTCTX_FLAG_RESOURCE_NAME_VALID | ACTCTX_FLAG_SET_PROCESS_DEFAULT | ACTCTX_FLAG_ASSEMBLY_DIRECTORY_VALID,
+        lpSource: source.as_mut_ptr(),
+        wProcessorArchitecture: 0,
+        wLangId: 0,
+        lpAssemblyDirectory: sys_dir.as_mut_ptr(),
+        lpResourceName: unsafe { mem::transmute(124usize) },
+        lpApplicationName: ptr::null_mut(),
+        hModule: ptr::null_mut()
+    };
+
+    unsafe {
+        let handle = CreateActCtxW(&mut act_ctx);
+        ActivateActCtx(handle, &mut activation_cookie);
+    }
+}
