@@ -1,9 +1,8 @@
 //! Provides traits and tools for displaying windows.
 
 use crate::io::storage::Storage;
-use crate::widget::NWidget;
 
-pub mod demowindow;
+pub mod dialog;
 
 #[cfg(windows)]
 #[derive(Clone)]
@@ -21,11 +20,6 @@ impl Frame {
         }
     }
 
-    /// Add a widget to the window
-    pub fn add(&self,widget: &dyn NWidget,frame: Frame) {
-
-    }
-
     /// Display the window
     pub fn show(&self) {
         use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
@@ -169,7 +163,7 @@ pub trait Application {
     }
 
     /// Processing at application startup (optional)
-    fn startup(&self,storage: Storage) {
+    fn startup(&self,_storage: Storage) {
     }
 
     /// Writing UI processes and events
@@ -311,12 +305,13 @@ pub trait Application {
     /// Returns WindowAttributes.
     fn attributes(&self) -> Attributes;
 
+    #[cfg(feature="nxui-awc")]
     fn advanced_options(&self) -> AdvancedOptions {
         AdvancedOptions::default()
     }
 
     /// Processing at application startup (optional)
-    fn startup(&mut self,storage: Storage) {
+    fn startup(&self,storage: Storage) {
 
     }
     /// Writing UI processes and events
